`0.0.1`_ (08-Apr-2021)
----------------------
- support for sending counters & timers to statsd over a TCP or UDP socket

.. _0.0.1: https://github.com/sprockets/sprockets-statsd/compare/832f8af7...0.0.1
